@@ -15,17 +15,16 @@ if not "twisted.internet.reactor" in sys.modules:
             kqreactor.install()
         except:
             try:
-                from twisted.internet import iocpreactor
-                iocpreactor.install()
+                from twisted.internet import pollreactor
+                pollreactor.install()
             except:
-                try:
-                    from twisted.internet import pollreactor
-                    pollreactor.install()
-                except:
-                    pass
+                pass
 
 from twisted.internet import reactor
-from twisted.internet.error import ReactorNotRunning
+try:
+    from twisted.internet.error import ReactorNotRunning
+except ImportError:
+    ReactorNotRunning = RuntimeError
 
 
 # thanks to Peter Norvig
